@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "crystal-mode" "0.1.0"
+(define-package "crystal-mode" "20260111.2220"
   "Major mode for editing Crystal files."
   '((emacs "24.4"))
   :url "https://github.com/crystal-lang-tools/emacs-crystal-mode"
-  :commit "0fe6815201bebe4c5ff6857bd541d95b05132b10"
-  :revdesc "0fe6815201be"
+  :commit "559e1d8ff9bb87a4e937978001386bfb58b113a0"
+  :revdesc "559e1d8ff9bb"
   :keywords '("languages" "crystal"))
